// https://www.codechef.com/problems/FLIPCOIN
// AC 0.21 s
#include <iostream>
#include <fstream>
#include <algorithm>
#include <vector>
using namespace std;


class SegTree {
public:
	SegTree(int n) : n {n}, sum {vector<long long>(4 * n)}, 
		                     lz {vector<long long>(4 * n)}
	{}
	
	void Update(int _L, int _R)
	{
		L = _L; R = _R;
		Update(1, 0, n - 1);
	}
	
	long long Query(int _L, int _R)
	{
		L = _L; R = _R;
		return Query(1, 0, n - 1);
	}
	
protected:	
	void Update(int x, int l, int r)
	{
		Propagate(x, l, r);
		
		if ( L <= l && r <= R )
		{
			lz[x] ^= 1;    
			Propagate(x, l, r);
			return;         
		}
		
		if (l > r || l > R || r < L) return;
		
		int m = (l + r) / 2;
		Update(2 * x, l, m);
		Update(2 * x + 1, m + 1, r);

		sum[x] = sum[2 * x] + sum[2 * x + 1];
	} 
	
	long long Query(int x, int l, int r)
	{
		Propagate(x, l, r);
		
		if (L <= l && r <= R)
			return sum[x]; 
		
		if (l > r || l > R || r < L) return 0;
		
		int m = (l + r) / 2;
		long long q1 = 0, q2 = 0;
	
		q1 = Query(2 * x, l, m);
		q2 = Query(2 * x + 1, m + 1, r);
			
		return q1 + q2; 
	}
	
	void Propagate(int& x, int &l, int &r)
	{
		if (lz[x])          
		{
			sum[x]  = (r - l + 1) - sum[x];
			if (l != r)                   // x has children
			{
				lz[2 * x]     ^= lz[x];   // flag the children
				lz[2 * x + 1] ^= lz[x];     
			}
			lz[x] = 0; 
		}
	}	
	
private:
	int n, L, R;
	vector<long long> sum, lz;  
	// sum[x] = nr de monede cu stema in sus in [l, r]
	// lz[x] = 1 daca monedele trebuie intoarse in [l, r], 0 daca nu 
};

int n, m, op, L, R;

int main()
{
    cin >> n >> m;
    SegTree s(n);	
    while (m--)
    {
        cin >> op >> L >> R;
        if ( op == 0 )
            s.Update(L, R);
        else
            cout << s.Query(L, R) << '\n';

    }
    return 0;
}
