// AC 0.17  sec
#include <iostream>
#include <fstream>
#include <algorithm>
using namespace std;


class SegTree {
public:
	SegTree(int _n) : n(_n) 
	{
		S = vector<long long>(4 * n); 
		cnt = vector<long long>(4 * n); 
	}
	
	void Update(int _L, int _R)
	{
		L = _L; R = _R;
		Update(1, 0, n - 1);
	}
	
	long long Query(int _L, int _R)
	{
		L = _L; R = _R;
		return Query(1, 0, n - 1);
	}
	
protected:	
	void Update(int x, int l, int r)
	{
		if ( L <= l && r <= R )
		{
			S[x]  = (r - l + 1) - S[x];   // update current node
			cnt[x] ^= 1;    // flag current node
			return;         // we're lazy: don't bother to update the sons  
		}
		
		PushDown(x, l, r); // we can't be lazy anymore
		
		int m = (l + r) / 2;
		if (L <= m) Update(2 * x, l, m);
		if (m < R)  Update(2 * x + 1, m + 1, r);

	//	if (l != r)      // if this node has children 
			S[x] = S[2 * x] + S[2 * x + 1];
	} 
	
	long long Query(int x, int l, int r)
	{
		if (L <= l && r <= R)
			return S[x]; 
		
		PushDown(x, l, r);   // push the information down the tree
		
		int m = (l + r) / 2;
		long long q1 = 0, q2 = 0;
		
		if (L <= m)
			q1 = Query(2 * x, l, m);
		if (m < R)
			q2 = Query(2 * x + 1, m + 1, r);
			
		return q1 + q2; 
	}
	
	void PushDown(int& x, int &l, int &r)
	{
		if ( l < r && cnt[x] )          // x has children and it's flagged 
		{
			cnt[2 * x]     ^= cnt[x];   // flag the children
			cnt[2 * x + 1] ^= cnt[x];     
		
			int m = (l + r) / 2;
	
			S[2 * x]  = (m - l + 1) - S[2 * x];  // update the children
			S[2 * x + 1]  = (r - m) - S[2 * x + 1];
			
			cnt[x] = 0; 
		}
	}	
	
private:
	int n, L, R;
	vector<long long> cnt, S;
};

int n, m, op, L, R;


int main()
{
	
    cin >> n >> m;
    SegTree s(n);	
    while (m--)
    {
        cin >> op >> L >> R;
        if ( op == 0 )
        {
            s.Update(L, R);

        }
        else
            cout << s.Query(L, R) << '\n';

    }
    return 0;
}
