// AC 0.05
// https://www.spoj.com/problems/POSTERS/
#include <fstream>
#include <iostream>
#include <vector>
#include <algorithm>
#include <set>
using namespace std;

class SegTree {
public:
	SegTree(int n) : 
		n {n}, c {vector<int>(4 * n)}, lazy {vector<int>(4 * n)}
	{}
	
	void Update(int a, int b, int color)
	{
		Update(1, 1, n, a, b, color);
	}
	
	int GetColor(int pos)
	{
		return GetColor(1, 1, n, pos);
	}
	
private:
	void Update(int x, int l, int r, int a, int b, int color)
	{
		if (a <= l && r <= b)
		{
			c[x] = color;
			lazy[x] = color;
			return;
		}
		
		PushDown(x);
		
		int m = (l + r) / 2;
		
		if (a <= m)	Update(2 * x, l, m, a, b, color);
		
		if (b > m)	Update(2 * x + 1, m + 1, r, a, b, color);
	}
	
	int GetColor(int x, int l, int r, int pos)
	{
		if (l == r)
			return c[x];
			
		PushDown(x);
		
		int m = (l + r) / 2;
		if (pos <= m)
			return GetColor(2 * x, l, m, pos);
		return GetColor(2 * x + 1, m + 1, r, pos);
	} 
	
	void PushDown(int x)
	{
		if (lazy[x])
		{
			c[2 * x]        = lazy[x];
			c[2 * x + 1]    = lazy[x];
			lazy[2 * x]     = lazy[x];
			lazy[2 * x + 1] = lazy[x];
			lazy[x] = 0;
		}
	}
	
	int n;
	vector<int> c;  // culoarea asociata intervalului (nr de ordine al posterului) 
	vector<int> lazy;
};

int main()
{
//	ifstream cin("posters.in");
//	ofstream cout("posters.out");
	ios_base::sync_with_stdio(false);
	cin.tie(0); cout.tie();
	int T, n;
	
	cin >> T;
	
	while (T--)
	{
		cin >> n;
		vector<int> li(n), ri(n);  // capetele intervalelor
		vector<int> a;
		a.reserve(2 * n);
		for (int i = 0; i < n; ++i)
		{
			cin >> li[i] >> ri[i];
			a.push_back(li[i]);
			a.push_back(ri[i]);
		}

		sort(a.begin(), a.end()); // O(n * log2(n))
		a.erase(unique(a.begin(), a.end()), a.end()); // O(n)
		
		for (int i = 0; i < n; ++i)  // O(n * log2(n))
			li[i] = lower_bound(a.begin(), a.end(), li[i]) - a.begin() + 1;
			
		for (int i = 0; i < n; ++i)  // O(n * log2(n))
			ri[i] = lower_bound(a.begin(), a.end(), ri[i]) - a.begin() + 1;
		
		int N = a.size();  // IMPORTANT -numarul de coordonate distincte poate fi mai mare decat n (am introdus 2*n valori (li, ri))
		SegTree st(N);
		
		for (int i = 0; i < n; ++i)
			st.Update(li[i], ri[i], i + 1);   // primul interval se coloreaza cu 1, al doilea cu 2, ....
		
		set<int> colors;
		for (int pos = 1; pos <= N; ++pos)   // am N pozitii unice in sirurile li si ri
		{
			int color = st.GetColor(pos);
			colors.insert(color);
		}
		
		cout << colors.size() << '\n';
	}
	
	
    return 0;
}
