#include <algorithm>
#include <iostream>
#include <fstream>
#include <vector>
using namespace std;

ifstream fin("kop14.in");
ofstream fout("kop.out");

#define mid ((l + r) / 2 - ((l + r) % 2 && (l + r) < 0))
const int Inf = 0x3f3f3f3f;

struct Point{
	int x, y;
	
	bool operator < (const Point& p) const
	{
		return x < p.x || (x == p.x && y < p.y);
	}
};

class Node {
public:
	Node(int l, int r)
		: l{l}, r{r},
		  vmax{0}, lazy{0},
		  ls{nullptr}, rs{nullptr}
	{
		if (l != r)
		{
			ls = new Node(l, mid);
			rs = new Node(mid + 1, r);
		}
	}
	
	void Update(int a, int b, int val)
	{
		Propagate();
		
		if (l > b || r < a || l > r)
			return;
		
		if (a <= l && r <=b)
		{
			lazy += val;
			Propagate();
			return;
		}
		
		ls->Update(a, b, val);
		rs->Update(a, b, val);
		
		vmax = max(ls->vmax, rs->vmax);
	}
	
	int GetMax()
	{
		Propagate();
		
		return vmax;
	}
	
private:
	void Propagate()
	{
		if (!lazy)
			return;
		
		vmax += lazy;
		if (l != r)
		{
			ls->lazy += lazy;
			rs->lazy += lazy;
		}
		
		lazy = 0;
	}

	int l, r;		// intervalul gestionat de nod
	int vmax;		// valoarea maxima pe acest interval
	int lazy;
	Node *ls, *rs;
};

using VI = vector<int>;
using VP = vector<Point>;

int W, H;
int n;
VP a;

int ymin{Inf}, ymax{-Inf};			// arborele de intervale va lucra in intervalul [ymin; ymax]

void ReadData();
void Solve();

int main()
{
	ReadData();
	Solve();
	
	fin.close();
	fout.close();
	return 0;
}

void ReadData()
{
	fin >> W >> H;
	fin >> n;
	
	a = VP(n);
	for (int i = 0; i < n; ++i)
	{
		fin >> a[i].x >> a[i].y;
		
		ymin = min(ymin, a[i].y);
		ymax = max(ymax, a[i].y);
	}
	
	sort(a.begin(), a.end());
	
	ymin -= H;
}

void Solve()
{
	Node* root = new Node(ymin, ymax);
	int ans{0};
	
	for (int i = 0, j = 0; i < n;)
	{
		for (; i < n && a[i].x - a[j].x <= W; ++i)
			root->Update(a[i].y - H, a[i].y, +1);
		
		ans = max(ans, root->GetMax());
		
		for (; j < i && a[i].x - a[j].x > W; ++j)
			root->Update(a[j].y - H, a[j].y, -1);
	}
	
	fout << ans << '\n';
}
