/* https://cses.fi/problemset/task/1740
 *
 * AC 0.17 s
 * Se dau n segmente orizontale si verticale.
 * Sa se determine numarul punctelor de intersectie.
 * Complexitate: O(N * log MAX_X)
 */
#include <iostream>
#include <algorithm>
#include <vector>
using namespace std;

const int MAX_N = 1e5,
          MAX_X = 1e6;

struct Event {
    int x, y1, y2, sgn;
    bool operator < (const Event& e) const
    {
		return x < e.x || (x == e.x && sgn > e.sgn);
	}
};

vector<Event> events;     // retine capetele (stanga si dreapta) a segm. orizontale si segmentele verticale
int st[4 * (2 * MAX_X)];  // st[nod] = nr de intersectii in intervalul de ORDONATE [l, r]  (pe axa OY)
long long cnt;            // coordonate negative: translatam cu 1e6 sa devina pozitive

long long Query(int x, int l, int r, int a, int b)
{
   if (a <= l && r <= b)  // recompun [a, b] din intervale [l, r] din arbore
       return st[x];      // ies, pt ca interv atasate fiilor nu mai pot aduce alte intevale pt completarea lui [a, b]

    int m;
    long long sum = 0;
	m = (l + r) / 2;

    if (a <= m)
		sum += Query(2 * x, l, m, a, b);
    if (b > m)
		sum += Query(2 * x + 1, m + 1, r,  a, b);
    return sum;
}

void Update(int x, int l, int r, int p, int v) // v trebuie adaugat in toate intervalele care-l contin pe p
{
    int m = (l + r) / 2;

    st[x] += v;
    if (l == r) return;   // updatez inclusiv frunza care e intervalul[p,p]
    if (p <= m)           // p apartine sigur intervalului [l,m]
       Update(2 * x, l, m, p, v); // drumul spre frunza e unic, deci else
    else
       Update(2 * x + 1, m + 1, r, p, v);
}

int main()
{
	ios_base::sync_with_stdio(0);
	cin.tie(0);
    int n, x1, y1, x2, y2;

    cin >> n;             // nr segmente
    for (int i = 0; i < n; i++)
    {
     	cin >> x1 >> y1 >> x2 >> y2;    // in sirul de evenimente plasam si puncte si segmente :

      	if (y1 == y2)     // orizontal
      	{
			events.emplace_back(x1, y1, 0, 1);  // sgn = +1 capat stanga seg, orizontal
			events.emplace_back(x2, y1, 0, -1); // sgn = -1 capat dreapta
		}
		else
			if (x1 == x2)    // vertical
				events.emplace_back(x1, y1, y2, 0);
    }

    sort(events.begin(), events.end()); // sorteaza evenimentele dupa x, apoi dupa sgn:
                                        // la acelasi x: sorteaza dupa capat stanga, segm vertical, capat dreapta
    // sweep
    for (auto [x, y1, y2, sgn] : events)
		if (sgn == 0)       // segm vertical
		   cnt += Query(1, 0, 2 * MAX_X, y1 + MAX_X, y2 + MAX_X); // nr de intersectii ale lui cu segm orizontale
		else
		   Update(1, 0, 2 * MAX_X, y1 + MAX_X, sgn); // introduce (sgn = +1) sau scoate (sgn = -1) un capat de segm orizontal in arbore

    cout << cnt;

    return 0;
}

